@@ -8,11 +8,11 @@ from app.utils.print import print_error
 from app.utils.validation import is_valid_key
 
 @click.command()
-@click.option("-k", "--key", prompt="Enter your OpenAI API key", prompt_required=not bool(load_key()))
+@click.option("--key", prompt="Enter your OpenAI API key")
 def main(key=None):
     if not key:
         key = load_key()
-        
+
     elif is_valid_key(key):
         save_key(key)
 
